% turbulent flow between two parallel plates - heat transfer model 
clc
clear all
close all

%% Iteration Process
d_min = 1e-3;
d_max = 0.01;
step = 0.1e-3;
n = (d_max-d_min)/step+1;
results = zeros(n,10)


results_ex(1,:) = {'v_dot in m^3/s','m_dot in kg/s','u in m/s','d in mm','Q_dot in kW','T_in in C','T_cout in C','T_w in C','Re','Nu'} % initializing the vector in which the results will be written
col = 1;

for d = d_min:step:d_max

%% input variables
u = 0.15;          % free stream velocity in m/s
wid = 2;        % width of flow and heating area in m
l_h = 0.5;      % length of heated area in flow direction in m
%d = 2e-3;       % distance between plates in m


% temperatures in C (guessed value for outlet Temp)
T_w = 90;       % temperature of heated wall in C
T_in= 15;       % water temp at inlet in C
T_out= 40;      % guessed outlet temperature in C

% Areas
A_flow=d*wid;  % Flow area in m^2
A = wid*l_h;      % Heat transfer area in m^2

% hydraulic diameter and flow rate
d_h = 2*d;          % hydraulic diameter for the case of flow through two parallel plates
v_dot = u*A_flow    % flow rate in m^3/s


%% Iteration Process
T_diff = 1;
i = 1;

while (abs(T_diff) > 0.01)
    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% look up values for different temperatures
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
water=load('water_properties.txt');             % load file that holds water properties for different temperatures [C] in the order: temp,density,specific heat,thermal conductivity, dynamic viscosity, Pr
T_m = (T_in+T_out)/2;                           %average fluid temperature

% density
rho_m = interp1(water(:,1),water(:,2),T_m);      % look up density @T_m [kg/m^3]
rho_w = interp1(water(:,1),water(:,2),T_w);      % look up density @T_w [kg/m^3]

% specific heat capacity
c_pm = interp1(water(:,1),water(:,3),T_m);      % look up specific heat capacity @T_m [J/(kg*K)]
c_pw = interp1(water(:,1),water(:,3),T_w);      % look up specific heat capacity @T_w [J/(kg*K)]

% thermal conductivity
k_m = interp1(water(:,1),water(:,4),T_m);      % look up thermal conductivity @T_m [W/(m*K)]
k_w = interp1(water(:,1),water(:,4),T_w);      % look up thermal conductivity @T_w [W/(m*K)]

% dynamic viscosity
mu_m = interp1(water(:,1),water(:,5),T_m);      % look up density @T_m [kg/(m*s)]
mu_w = interp1(water(:,1),water(:,5),T_w);      % look up density @T_w [kg/(m*s)]

% kinematic viscosity
nu_m = mu_m/rho_m;      % kinematic viscosity of fluid (water) in m^2/s @T_m
nu_w = mu_w/rho_w;      % kinematic viscosity of fluid (water) in m^2/s @T_w

% Prandtl-number
Pr_m = c_pm*mu_m/k_m;   % Prandtl number @T_m
Pr_w = c_pm*mu_w/k_w;   % Prandtl number @T_w



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%                                          
% check Reynolds number --> Laminar or Turbulent flow?
% Calculation of Nusselt number and heat flow
% these equations were taken from "VDI Wrmeatlas - 9. Auflage 2002"
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
Re = u*d_h/nu_m;    % Reynolds number for the given input values

if Re <= 3600       % The flow is assumed to be laminar upto a Reynoldsnumber of 3600
% Laminar flow
    T_ln=((T_w-T_in)-(T_w-T_out))/log((T_w-T_in)/(T_w-T_out));      % logarithmic temperature difference in C
    Nu_1 = 4.861;                                                   % For heating of only one of the plates
    Nu_2 = 1.841*(Re*Pr_m*d_h/l_h)^(1/3);
    Nu_m = (Nu_1^3+Nu_2^3)^(1/3);           % Average nusselt number
    Nu = Nu_m*(Pr_m/Pr_w)^0.11;           % Average nusselt number taking into account the direction of the heat transfer
    alpha_l = Nu*k_m/d_h;                 % convective heat transfer coefficient
    Q_dot = A*alpha_l*T_ln;                 % Heat flow in W
    
    
else               % If the Reynoldsnumber is above 3600 the flow is treated as turbulent
    disp('the current Reynolds number is higher than the specified limit of 3600')
    pause
% % turbulent flow  
%                                           
% % check Reynolds number and Prandtl number if within boundary conditions
% if Pr_m <= 0.5 || Pr_m > 100
%     disp(['Warning! Pr should be in the range 0.5 < Pr < 100 currently Pr = ',num2str(Pr_m)])
%     pause
% end
% if (Re <= 3e4 || Re > 10^6)
%     disp(['Warning! Re should be in the range 3*10^4 <= Re < 10^6 currently Re = ',num2str(Re)])
%     pause
% end
% 
% T_ln=((T_w-T_in)-(T_w-T_out))/log((T_w-T_in)/(T_w-T_out));      % logarithmic temperature difference in C
% xi = (1.8*log10(Re)-1.5)^-2;
% 
% Nu_pipe = ((xi/8)*Re*Pr_m)/(1+12.7*(xi/8)^(0.5)*(Pr_m^(2/3)-1))*(1+(d_h/l_h)^(2/3));  % Nusselt number if the flow took place in a pipe
% Nu_mpp = 0.86 * Nu_pipe;                    % average nusselt number without taking into account the direction of the heat flow.
% Nu = Nu_mpp*(Pr_m/Pr_w)^0.11;               % average nusselt number
% 
% alpha = Nu*k_m/d_h;                         % convective heat transfer coefficient
% Q_dot = A*alpha*T_ln;                       % heat flow in W

end



T_cout = Q_dot/(A_flow*rho_m*c_pm*u)+T_in;  % calculated water temerature at outflow
T_diff = T_cout-T_out;

if T_cout > T_w
    disp('the calculated water temperature at the outlet is higher than the defined wall temperature!');
    pause
end
disp(['Results from Interation number ',num2str(i),':  ', 'Q_dot = ',num2str(Q_dot),'  T_cout = ',num2str(T_cout),'  T_diff = ',num2str(T_diff)])

i = i + 1;
T_out = (T_cout+T_out)/2;   % update outlet temperature for next iteration step
m_dot = rho_m*v_dot;        % mass flow rate at given temperature and volumetric flow rate

end

Q_dot=Q_dot/1000        % W --> kW
d= d*1000               % m --> mm
results(col,:) = [v_dot,m_dot,u,d,Q_dot,T_in,T_cout,T_w,Re,Nu];
col = col+1
results_ex(col,:) = {v_dot,m_dot,u,d,Q_dot,T_in,T_cout,T_w,Re,Nu};

end

xlswrite('Lamiar-Flow-results.xls', results_ex, 'velocity-sweep-0-15', 'A1');
